@@ -14,6 +14,7 @@ KEY_MOTION_DETECTION = "motion_detection"
 KEY_MOVIES = "movies"
 KEY_NAME = "name"
 KEY_PATH = "path"
+KEY_ROOT_DIRECTORY = "root_directory"
 KEY_STILL_IMAGES = "still_images"
 KEY_STREAMING_PORT = "streaming_port"
 KEY_STREAMING_AUTH_MODE = "streaming_auth_mode"
@@ -37,6 +38,9 @@ KEY_WEB_HOOK_STORAGE_HTTP_METHOD = "web_hook_storage_http_method"
 KEY_WEB_HOOK_STORAGE_URL = "web_hook_storage_url"
 
 KEY_HTTP_METHOD_GET = "GET"
+KEY_HTTP_METHOD_POST_JSON = "POSTj"
+KEY_HTTP_METHOD_POST_QUERY = "POST"
+KEY_HTTP_METHOD_POST_FORM = "POSTf"
 
 # Conversion specifiers.
 # https://motion-project.github.io/motion_config.html#conversion_specifiers
